==> tsc_blue_print-0.0.4.tar.gz: lib/tsc_blue_print.dart <==

import 'package:flutter/services.dart';

class TscBluePrint {

  static const MethodChannel _channel = const MethodChannel('tsc_blue_print');

  Future<String?> getPlatformVersion() async {
    return  await _channel.invokeMethod('getPlatformVersion');
  }

  Future<String> print_blue({
    required String ipAddress,
    required int widthPaper,
    required int heightPaper,
    required String tara,
    required String peso,
    required String bruto,
    required String fecha_prod,
    required String vendor,
    required String expiryDate,
    required String productCode
  }) async {

    final String result = await _channel.invokeMethod('ble_print', {
      'ipAddress': ipAddress,
      'widthPaper' : widthPaper,
      'heightPaper' : heightPaper,
      'tara': tara,
      'peso': peso,
      'bruto': bruto,
      'fecha_prod': fecha_prod,
      'expiryDate': expiryDate,
      'vendor': vendor,
      'productCode': productCode,
    });
    return result;

  }

  Future<String> print_wifi({
    required String ipAddress,
    required int widthPaper,
    required int heightPaper,
    required String tara,
    required String peso,
    required String bruto,
    required String fecha_prod,
    required String vendor,
    required String expiryDate,
    required String productCode,
  }) async {

    final String result = await _channel.invokeMethod('wifi_print', {
      'ipAddress': ipAddress,
      'widthPaper' : widthPaper,
      'heightPaper' : heightPaper,
      'tara': tara,
      'peso': peso,
      'bruto': bruto,
      'fecha_prod': fecha_prod,
      'expiryDate': expiryDate,
      'vendor': vendor,
      'productCode': productCode,
    });
    return result;

  }


}

==> tsc_blue_print-0.0.5.tar.gz: lib/tsc_blue_print.dart <==

import 'package:flutter/services.dart';

class TscBluePrint {

  static const MethodChannel _channel = const MethodChannel('tsc_blue_print');

  Future<String?> getPlatformVersion() async {
    return  await _channel.invokeMethod('getPlatformVersion');
  }

  Future<String> printBlue({
    required String ipAddress,
    required int widthPaper,
    required int heightPaper,
    required String tara,
    required String peso,
    required String bruto,
    required String fecha_prod,
    required String vendor,
    required String expiryDate,
    required String productCode
  }) async {

    final String result = await _channel.invokeMethod('ble_print', {
      'ipAddress': ipAddress,
      'widthPaper' : widthPaper,
      'heightPaper' : heightPaper,
      'tara': tara,
      'peso': peso,
      'bruto': bruto,
      'fecha_prod': fecha_prod,
      'expiryDate': expiryDate,
      'vendor': vendor,
      'productCode': productCode,
    });
    return result;

  }

  Future<String> printWifi({
    required String ipAddress,
    required int widthPaper,
    required int heightPaper,
    required String tara,
    required String peso,
    required String bruto,
    required String fechaProd,
    required String vendor,
    required String expiryDate,
    required String productCode,
  }) async {

    final String result = await _channel.invokeMethod('wifi_print', {
      'ipAddress': ipAddress,
      'widthPaper' : widthPaper,
      'heightPaper' : heightPaper,
      'tara': tara,
      'peso': peso,
      'bruto': bruto,
      'fecha_prod': fechaProd,
      'expiryDate': expiryDate,
      'vendor': vendor,
      'productCode': productCode,
    });
    return result;

  }


}
